BidAdnId enum
竞价回传时的ADN_ID枚举
Values
- ZJ → const BidAdnId
-
ZJSDK
const BidAdnId(1) - PANGLE → const BidAdnId
-
穿山甲/头条广告
const BidAdnId(2) - GDT → const BidAdnId
-
优量汇/广点通/腾讯广告
const BidAdnId(3) - BD → const BidAdnId
-
百度联盟/百青藤
const BidAdnId(4) - MINTEGRAL → const BidAdnId
-
Mintegral
const BidAdnId(5) - KS → const BidAdnId
-
快手联盟
const BidAdnId(6) - TANX → const BidAdnId
-
Tanx
const BidAdnId(7) - QM → const BidAdnId
-
趣盟/趣头条
const BidAdnId(8) - SIGMOB → const BidAdnId
-
Sigmob
const BidAdnId(9) - OTHER → const BidAdnId
-
其他
const BidAdnId(10)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- val → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited