ZJCustomController class

隐私权限控制

Constructors

ZJCustomController({bool canReadLocation = true, double longitude = 0.0000, double latitude = 0.0000, bool canUsePhoneState = true, String imei = "", bool canUseAndroidId = true, String androidId = "", bool canUseMacAddress = true, String macAddress = "", bool canUseOaid = true, String oaid = "", bool canUseGaid = true, String gaid = "", bool canUseNetworkState = true, bool canUseStoragePermission = true, bool canReadInstalledPackages = true, List<String> installedPackages = defaultInstalledPackages, bool canRecordAudio = true, bool canReadBootId = true, bool canReadNearbyWifiList = true, bool canUseSensor = true, bool canUseSimOperator = true, String simOperatorCode = "", String simOperatorName = "", bool? canUseLocation = true, bool? canUseWiFiBSSID = true, bool? canUseIDFA = true, bool? canUseIDFV = true, bool? canUsePhoneStatus = true, bool? canUseDeviceId = true, bool? canUseOSVersionName = true, bool? canUseOSVersionCode = true, bool? canUsePackageName = true, bool? canUseAppVersionName = true, bool? canUseAppVersionCode = true, bool? canUseBrand = true, bool? canUseModel = true, bool? canUseScreen = true, bool? canUseOrient = true, bool? canUseNetworkType = true, bool? canUseMNC = true, bool? canUseMCC = true, bool? canUseOSLanguage = true, bool? canUseTimeZone = true, bool? canUseUserAgent = true, bool? isCanUseMotionManager = true, bool? canUseIPAddress = true, bool? isOnlyICPNumber = false, bool? turnOnTeenMode = false})

Properties

androidId String
AndroidID
getter/setter pair
canReadBootId bool
是否允许SDK主动获取BootID
getter/setter pair
canReadInstalledPackages bool
主动读取已安装应用列表
getter/setter pair
canReadLocation bool
主动获取定位
getter/setter pair
canReadNearbyWifiList bool
是否允许获取附近的Wifi列表
getter/setter pair
canRecordAudio bool
是否允许SDK在申明和授权了的情况下使用录音权限
getter/setter pair
canUseAndroidId bool
主动获取AndroidID
getter/setter pair
canUseAppVersionCode bool?
是否允许获取手机应用版本号,默认为YES, 仅iOS生效
getter/setter pair
canUseAppVersionName bool?
是否允许获取手机应用版本名,默认为YES, 仅iOS生效
getter/setter pair
canUseBrand bool?
是否允许获取手机设备品牌,默认为YES, 仅iOS生效
getter/setter pair
canUseDeviceId bool?
收否允许获取手机DeviceId,默认为YES, 仅iOS生效
getter/setter pair
canUseGaid bool
主动获取GAID
getter/setter pair
canUseIDFA bool?
是否允许SDK获取IDFA,默认为YES, 仅iOS生效
getter/setter pair
canUseIDFV bool?
是否允许SDK获取IDFV,默认为YES, 仅iOS生效
getter/setter pair
canUseIPAddress bool?
是否允许获取IP地址
getter/setter pair
canUseLocation bool?
是否允许SDK使用定位权限,默认为YES, 仅iOS生效
getter/setter pair
canUseMacAddress bool
主动获取MAC地址
getter/setter pair
canUseMCC bool?
是否允许获取手机移动国家代码,默认为YES, 仅iOS生效
getter/setter pair
canUseMNC bool?
是否允许获取手机移动网络代码,默认为YES, 仅iOS生效
getter/setter pair
canUseModel bool?
是否允许获取手机设备型号,默认为YES, 仅iOS生效
getter/setter pair
canUseNetworkState bool
获取网络状态
getter/setter pair
canUseNetworkType bool?
是否允许获取手机网络类型,默认为YES, 仅iOS生效
getter/setter pair
canUseOaid bool
主动获取OAID
getter/setter pair
canUseOrient bool?
是否允许获取手机屏幕方向,默认为YES, 仅iOS生效
getter/setter pair
canUseOSLanguage bool?
是否允许获取手机系统语言,默认为YES, 仅iOS生效
getter/setter pair
canUseOSVersionCode bool?
是否允许获取手机系统版本号,默认为YES, 仅iOS生效
getter/setter pair
canUseOSVersionName bool?
是否允许获取手机系统版本名,默认为YES, 仅iOS生效
getter/setter pair
canUsePackageName bool?
是否允许获取手机应用包名,默认为YES, 仅iOS生效
getter/setter pair
canUsePhoneState bool
主动获取设备信息
getter/setter pair
canUsePhoneStatus bool?
是否允许获取手机状态信息,默认为YES, 仅iOS生效
getter/setter pair
canUseScreen bool?
是否允许获取手机屏幕分辨率,默认为YES, 仅iOS生效
getter/setter pair
canUseSensor bool
是否允许获取传感器信息
getter/setter pair
canUseSimOperator bool
是否允许 SDK 主动获取运营商信息
getter/setter pair
canUseStoragePermission bool
使用存储
getter/setter pair
canUseTimeZone bool?
是否允许获取手机时区,默认为YES, 仅iOS生效
getter/setter pair
canUseUserAgent bool?
是否允许获取手机User Agent,默认为YES, 仅iOS生效
getter/setter pair
canUseWiFiBSSID bool?
是否允许SDK使用WiFi BSSID,默认为YES, 仅iOS生效
getter/setter pair
gaid String
GAID
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imei String
IMEI
getter/setter pair
installedPackages List<String>
已安装应用列表
getter/setter pair
isCanUseMotionManager bool?
是否允许SDK主动使用互动组件能力(摇一摇、扭一扭等),默认为YES, 仅iOS生效
getter/setter pair
isOnlyICPNumber bool?
短剧设置是否返回带有备案号的, true仅有备案号、false全量内容(默认),仅iOS生效
getter/setter pair
latitude double
纬度
getter/setter pair
longitude double
经度
getter/setter pair
macAddress String
MAC地址
getter/setter pair
oaid String
OAID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simOperatorCode String
当 canUseSimOperator==false 时,可传入运营商编码,例如:46000
getter/setter pair
simOperatorName String
当 canUseSimOperator==false 时,可传入运营商名称,例如:中国移动
getter/setter pair
turnOnTeenMode bool?
短剧设置是否打开青少年模式,默认不打开,仅iOS生效
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultInstalledPackages → const List<String>